/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/mozilla-1.9.2-linux64-xulrunner/build/dom/interfaces/svg/nsIDOMSVGSymbolElement.idl
 */

#ifndef __gen_nsIDOMSVGSymbolElement_h__
#define __gen_nsIDOMSVGSymbolElement_h__


#ifndef __gen_nsIDOMSVGElement_h__
#include "nsIDOMSVGElement.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMSVGSymbolElement */
#define NS_IDOMSVGSYMBOLELEMENT_IID_STR "86092181-a5db-4a89-be03-07dcc14d426e"

#define NS_IDOMSVGSYMBOLELEMENT_IID \
  {0x86092181, 0xa5db, 0x4a89, \
    { 0xbe, 0x03, 0x07, 0xdc, 0xc1, 0x4d, 0x42, 0x6e }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIDOMSVGSymbolElement : public nsIDOMSVGElement {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMSVGSYMBOLELEMENT_IID)

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMSVGSymbolElement, NS_IDOMSVGSYMBOLELEMENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMSVGSYMBOLELEMENT \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMSVGSYMBOLELEMENT(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMSVGSYMBOLELEMENT(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMSVGSymbolElement : public nsIDOMSVGSymbolElement
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMSVGSYMBOLELEMENT

  nsDOMSVGSymbolElement();

private:
  ~nsDOMSVGSymbolElement();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMSVGSymbolElement, nsIDOMSVGSymbolElement)

nsDOMSVGSymbolElement::nsDOMSVGSymbolElement()
{
  /* member initializers and constructor code */
}

nsDOMSVGSymbolElement::~nsDOMSVGSymbolElement()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMSVGSymbolElement_h__ */
